////////////////////////////////////////////////////////////////////////////////
//
// Filename: 	sintable.v
//
// Project:	Verilog Tutorial Example file
//
// Purpose:	This is a very simple sinewave table lookup approach
//		approach to generating a sine wave.  It has the lowest latency
//	among all sinewave generation alternatives.
//
// Creator:	Dan Gisselquist, Ph.D.
//		Gisselquist Technology, LLC
//
////////////////////////////////////////////////////////////////////////////////
//
// Written and distributed by Gisselquist Technology, LLC
//
// This program is hereby granted to the public domain.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTIBILITY or
// FITNESS FOR A PARTICULAR PURPOSE.
//
////////////////////////////////////////////////////////////////////////////////
//
//
`default_nettype	none
//
module	sintable(i_clk, i_reset, i_ce, i_phase, o_val);
	//
	parameter	PW =12, // Number of bits in the input phase
			OW =16; // Number of output bits
	//
	input	wire			i_clk, i_reset, i_ce;
	input	wire	[(PW-1):0]	i_phase;
	output	reg	[(OW-1):0]	o_val;

	reg	[(OW-1):0]		tbl	[0:((1<<PW)-1)];

	initial	$readmemh("sintable.hex", tbl);

	initial	o_val = 0;
	always @(posedge i_clk)
	if (i_reset)
		o_val <= 0;
	else if (i_ce)
		o_val <= tbl[i_phase];

endmodule
